@@ -112,35 +112,45 @@ class Generation(RevPySam, ABC):
         return res_mean, out_req_nomeans
 
     @staticmethod
-    def tz_check(sam_sys_inputs, meta):
-        """Check timezone input and use json config tz if not in resource meta.
+    def tz_elev_check(sam_sys_inputs, site_sys_inputs, meta):
+        """Check timezone+elevation input and use json config
+        timezone+elevation if not in resource meta.
 
         Parameters
         ----------
         sam_sys_inputs : dict
             Site-agnostic SAM system model inputs arguments.
+        site_sys_inputs : dict
+            Optional set of site-specific SAM system inputs to complement the
+            site-agnostic inputs.
         meta : pd.DataFrame
             1D table with resource meta data.
 
         Returns
         -------
         meta : pd.DataFrame
-            1D table with resource meta data. If meta was not originally set in
-            the resource meta data, but was set as "tz" or "timezone" in the
-            SAM model input parameters json file, timezone will be added to
-            this instance of meta.
+            1D table with resource meta data. Will include "timezone"
+            and "elevation" from the sam and site system inputs if found.
         """
 
         if meta is not None:
-            if 'timezone' not in meta:
-                if 'tz' in sam_sys_inputs:
-                    meta['timezone'] = int(sam_sys_inputs['tz'])
-                elif 'timezone' in sam_sys_inputs:
+            if sam_sys_inputs is not None:
+                if 'elevation' in sam_sys_inputs:
+                    meta['elevation'] = sam_sys_inputs['elevation']
+                if 'timezone' in sam_sys_inputs:
                     meta['timezone'] = int(sam_sys_inputs['timezone'])
-                else:
-                    msg = ('Need timezone input to run SAM gen. Not found in '
-                           'resource meta or technology json input config.')
-                    raise SAMExecutionError(msg)
+
+            # site-specific inputs take priority over generic system inputs
+            if site_sys_inputs is not None:
+                if 'elevation' in site_sys_inputs:
+                    meta['elevation'] = site_sys_inputs['elevation']
+                if 'timezone' in site_sys_inputs:
+                    meta['timezone'] = int(site_sys_inputs['timezone'])
+
+            if 'timezone' not in meta:
+                msg = ('Need timezone input to run SAM gen. Not found in '
+                       'resource meta or technology json input config.')
+                raise SAMExecutionError(msg)
 
         return meta
 
@@ -393,7 +403,7 @@ class Solar(Generation, ABC):
             resource = self.drop_leap(resource)
 
         sam_sys_inputs = self.set_latitude_tilt_az(sam_sys_inputs, meta)
-        meta = self.tz_check(sam_sys_inputs, meta)
+        meta = self.tz_elev_check(sam_sys_inputs, site_sys_inputs, meta)
 
         # don't pass resource to base class, set in set_nsrdb instead.
         super().__init__(meta, sam_sys_inputs, output_request,
@@ -1105,7 +1115,7 @@ class WindPower(Generation):
         if drop_leap:
             resource = self.drop_leap(resource)
 
-        meta = self.tz_check(sam_sys_inputs, meta)
+        meta = self.tz_elev_check(sam_sys_inputs, site_sys_inputs, meta)
 
         # don't pass resource to base class, set in set_wtk instead.
         super().__init__(meta, sam_sys_inputs, output_request,
