@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 # pylint: disable=all
+# flake8: noqa
 """
 reV Supply Curve Aggregation command line interface (cli).
 """
@@ -26,6 +27,7 @@ logger = logging.getLogger(__name__)
 
 
 @click.group()
+@click.version_option(version=__version__)
 @click.option('--name', '-n', default='reV-agg', type=STR,
               show_default=True,
               help='Job name. Default is "reV-agg".')
@@ -39,14 +41,6 @@ def main(ctx, name, verbose):
     ctx.obj['VERBOSE'] = verbose
 
 
-@main.command()
-def version():
-    """
-    print version
-    """
-    click.echo(__version__)
-
-
 @main.command()
 def valid_config_keys():
     """
@@ -257,7 +251,8 @@ def from_config(ctx, config_file, verbose):
               'return a scalar value to multiply the capital cost by. '
               'Independent variables in the equation should match the names '
               'of the columns in the reV supply curve aggregation table. '
-              'This will not affect offshore wind LCOE.')
+              'This equation may use numpy functions with the package prefix '
+              '"np". This will not affect offshore wind LCOE.')
 @click.option('--out_dir', '-o', type=STR, default='./',
               show_default=True,
               help='Directory to save aggregation summary output.')
